@@ -6,17 +6,19 @@ import threading
 import logging
 import traceback
 import random
+
+import pygame.sprite
 from pgzero.actor import Actor
-from fzq_scnu import Input
-try:
-    # 图形化编程软件的路径
-    sys.path.append('.\\resources\\assets\\class\\emulator_files\\')
-    import constants
-except Exception:
-    # 用于测试的个人路径
-    # from fzq_scnu.fzrunner import files_path
-    sys.path.append('C:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\')
-    import constants
+from fzq_scnu import Input, constants
+# try:
+#     # 图形化编程软件的路径
+#     sys.path.append('.\\resources\\assets\\class\\emulator_files\\')
+#     import constants
+# except Exception:
+#     # 用于测试的个人路径
+#     # from fzq_scnu.fzrunner import files_path
+#     sys.path.append('con:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\')
+#     import constants
 '''
 已有background_rect为Rect((200, 6), (900, 650))
 红外被遮挡（可利用rect碰撞,目前使用颜色检测），还有设置按钮切换左右红外未写
@@ -59,10 +61,10 @@ hongwai_quantity = {'left': ['none', 'none'], 'right': ['none', 'none'], 'l_r_ex
 transmit_right = {}
 transmit_left = {}
 text_box = {}
-
-
 # -------------------------------------------------------------------------------------------------------
-class gpio_distribute:
+
+
+class Distribute:
     # io口或pwm口的分配，及相应的报错
     def __init__(self, io_pwm_uw_num=None, io_pwm_uw='io'):
         self.io_pwm_uw_num = io_pwm_uw_num
@@ -142,37 +144,40 @@ class gpio_distribute:
 
 # 主要部分
 # 以下为gpio改为fzgpio
-class io:
-    def __init__(self, io_num=None):
+class Io(object):
+    def __init__(self, io_num: int = None):
         self.gpioio = io_num
         self.io_img_name = 'low'
         if self.gpioio or self.gpioio == 0:
-            page_info = gpio_distribute(self.gpioio, 'io').raise_exception()
-            gpio_distribute.message(self.io_img_name, 'IO', 'IO', self.gpioio, ' ', ' ', page_info)
+            page_info = Distribute(self.gpioio, 'io').raise_exception()
+            Distribute.message(self.io_img_name, 'IO', 'IO', self.gpioio, ' ', ' ', page_info)
             self.iocount = msg_dict['num_count']
         self.ioin = 404
-        self.inorout = '未设置输入输出模式'
-        self.dianping = '未设置高低电平'
+        self.in_or_out = '未设置输入输出模式'
+        self.dian_ping = '未设置高低电平'
 
-    def setinout(self, inorout):
-        self.inorout = inorout
-        if self.inorout == 'IN':
+    def set_io_mode(self, gpio_mode: str):
+        pass
+
+    def set_in_out(self, in_or_out: str):
+        self.in_or_out = in_or_out
+        if self.in_or_out == 'IN':
             transmit_right[self.iocount][6][0] = 'IN'
-        elif self.inorout == 'OUT':
+        elif self.in_or_out == 'OUT':
             transmit_right[self.iocount][6][0] = 'OUT'
         else:
             msg_dict['exit'] = True
             print('未设置IO口输入输出模式或未知错误')
             sys.exit(0)
 
-    def setioout(self, dianping):
-        self.dianping = dianping
+    def set_io_out(self, dian_ping: str):
+        self.dian_ping = dian_ping
         if transmit_right[self.iocount][6][0] == 'OUT':
             # GPIO输出高or低电平
-            if self.dianping == 'HIGH':
+            if self.dian_ping == 'HIGH':
                 transmit_right[self.iocount][6][1] = 'HIGH'
                 transmit_right[self.iocount][0] = 'high'
-            elif self.dianping == 'LOW':
+            elif self.dian_ping == 'LOW':
                 transmit_right[self.iocount][6][1] = 'LOW'
                 transmit_right[self.iocount][0] = 'low'
             else:
@@ -184,7 +189,7 @@ class io:
             print('IO口未设置为输出模式,请检查')
             sys.exit(0)
 
-    def getioin(self):
+    def get_io_in(self):
         if transmit_right[self.iocount][6][0] == 'IN':
             if msg_dict['car_expansion_collide']:
                 self.ioin = 0
@@ -199,21 +204,21 @@ class io:
             print('未设置IO口为输入模式或未知错误')
             sys.exit(0)
 
-    def cleanio(self):
+    def clean_io(self):
         self.ioin = 404
-        self.inorout = '未设置输入输出模式'
-        self.dianping = '未设置高低电平'
+        self.in_or_out = '未设置输入输出模式'
+        self.dian_ping = '未设置高低电平'
         transmit_right[self.iocount][6][0] = ' '
         transmit_right[self.iocount][6][1] = ' '
 
 
-class io2pwm:
-    def __init__(self, io_num=None, freq=50, duty=50):
+class IoToPwm(object):
+    def __init__(self, io_num: int = None, freq: int = 50, duty: int = 50):
         self.iopwm_io = io_num
         self.iopwm_img_name = 'low'
         if self.iopwm_io or self.iopwm_io == 0:
-            page_info = gpio_distribute(self.iopwm_io, 'io').raise_exception()
-            gpio_distribute.message(self.iopwm_img_name, 'IO', 'IO', self.iopwm_io, ' ', ' ', page_info)
+            page_info = Distribute(self.iopwm_io, 'io').raise_exception()
+            Distribute.message(self.iopwm_img_name, 'IO', 'IO', self.iopwm_io, ' ', ' ', page_info)
             self.iopwmcount = msg_dict['num_count']
         self.iopwm_freq = freq
         self.iopwm_duty = duty
@@ -240,13 +245,13 @@ class io2pwm:
         transmit_right[self.iopwmcount][6][1] = '' + '0' + '%'
 
 
-class PWM:
-    def __init__(self, pwm_io=None):
+class PWM(object):
+    def __init__(self, pwm_io: int = None):
         self.pwm_io = pwm_io
         self.pwm_img_name = 'low'
         if self.pwm_io or self.pwm_io == 0:
-            page_info = gpio_distribute(self.pwm_io, 'pwm').raise_exception()
-            gpio_distribute.message(self.pwm_img_name, 'PWM', 'PWM', self.pwm_io, ' ', ' ', page_info)
+            page_info = Distribute(self.pwm_io, 'pwm').raise_exception()
+            Distribute.message(self.pwm_img_name, 'PWM', 'PWM', self.pwm_io, ' ', ' ', page_info)
             self.pwmcount = msg_dict['num_count']
         self.pwm_duty = 50
         self.pwm_freq = 262
@@ -273,13 +278,13 @@ class PWM:
         transmit_right[self.pwmcount][6][1] = '' + '0' + '%'
 
 
-class csb:
-    def __init__(self, uw_num=None):
+class CSB(object):
+    def __init__(self, uw_num: int = None):
         self.csbuw = uw_num
         self.csb_img_name = 'chaos0'
         if self.csbuw or self.csbuw == 0:
-            page_info = gpio_distribute(self.csbuw, 'uw').raise_exception()
-            gpio_distribute.message(self.csb_img_name, '超声波传感器', 'UW', self.csbuw, '关', ' ', page_info)
+            page_info = Distribute(self.csbuw, 'uw').raise_exception()
+            Distribute.message(self.csb_img_name, '超声波传感器', 'UW', self.csbuw, '关', ' ', page_info)
             self.csbcount = msg_dict['num_count']
             msg_dict['csbs'][0] = 1  # 标记初始化成功
         # self.trig_p = uw_num
@@ -335,13 +340,13 @@ class CsbProducing:
 # -------------------------------------------------------------------------------------------------------
 
 
-class beep:
-    def __init__(self, beepio=None):
+class Beep(object):
+    def __init__(self, beepio: int = None):
         self.beepio = beepio
         self.beep_img_name = 'beep'
         if self.beepio or self.beepio == 0:
-            page_info = gpio_distribute(self.beepio, 'io').raise_exception()
-            gpio_distribute.message(self.beep_img_name, '蜂鸣器', 'IO', self.beepio, '关', ' ', page_info)
+            page_info = Distribute(self.beepio, 'io').raise_exception()
+            Distribute.message(self.beep_img_name, '蜂鸣器', 'IO', self.beepio, '关', ' ', page_info)
             self.beepcount = msg_dict['num_count']
         # self.data = 0
         self.beep_while = False
@@ -358,7 +363,7 @@ class beep:
                 else:
                     sys.exit(0)
 
-    def beep_s(self, seconds=1):
+    def beep_s(self, seconds: int = 1):
         self.beep_while = True
         beep_thead = threading.Thread(target=self.beep_theading, daemon=True)
         time.sleep(seconds)
@@ -375,13 +380,13 @@ class beep:
         transmit_right[self.beepcount][0] = 'beep'
 
 
-class led:
-    def __init__(self, ledio=None):
+class Led(object):
+    def __init__(self, ledio: int = None):
         self.ledio = ledio
         self.led_img_name = 'led_off1'
         if self.ledio or self.ledio == 0:
-            page_info = gpio_distribute(self.ledio, 'io').raise_exception()
-            gpio_distribute.message(self.led_img_name, 'Led', 'IO', self.ledio, '灭', '', page_info)
+            page_info = Distribute(self.ledio, 'io').raise_exception()
+            Distribute.message(self.led_img_name, 'Led', 'IO', self.ledio, '灭', '', page_info)
             self.ledcount = msg_dict['num_count']
 
     def openled(self):
@@ -416,13 +421,13 @@ class led:
 # -------------------------------------------------------------------------------------------------------
 
 
-class tmp_hum:
-    def __init__(self, t_h_io=None):
+class TempHump(object):
+    def __init__(self, t_h_io: int = None):
         self.tmp_io = t_h_io
         self.tmp_hum_img_name = 'wsdu1'
         if self.tmp_io or self.tmp_io == 0:
-            page_info = gpio_distribute(self.tmp_io, 'io').raise_exception()
-            gpio_distribute.message(self.tmp_hum_img_name, '温湿度传感器', 'IO', self.tmp_io, '关', '', page_info)
+            page_info = Distribute(self.tmp_io, 'io').raise_exception()
+            Distribute.message(self.tmp_hum_img_name, '温湿度传感器', 'IO', self.tmp_io, '关', '', page_info)
             self.tmp_humcount = msg_dict['num_count']
         self.temp = None
         self.humi = None
@@ -460,10 +465,10 @@ class tmp_hum:
             else:
                 tmp_hum_data['temp'] = str(self.temp)
                 tmp_hum_data['humi'] = str(self.humi)
-                text_box['temp_humi'] = {'当前温度(℃): ：': texts_pos_sitting['当前温度(℃): '][0],
-                                         tmp_hum_data['temp'] + '℃': texts_pos_sitting['当前温度(℃): '][1],
-                                         '当前湿度(%): ：': texts_pos_sitting['当前湿度(%): '][0],
-                                         tmp_hum_data['humi'] + '%': texts_pos_sitting['当前湿度(%): '][1]}
+                text_box['temp_humi'] = {'当前温度(℃): ：': texts_pos_sitting['当前温度(℃):'][0],
+                                         tmp_hum_data['temp'] + '℃': texts_pos_sitting['当前温度(℃):'][1],
+                                         '当前湿度(%): ：': texts_pos_sitting['当前湿度(%):'][0],
+                                         tmp_hum_data['humi'] + '%': texts_pos_sitting['当前湿度(%):'][1]}
             transmit_right[self.tmp_humcount][6][0] = '开'
         else:
             print("温湿度传感器：获取温湿度失败")
@@ -474,16 +479,16 @@ class tmp_hum:
             return True
 
 
-class hongwai:
-    def __init__(self, hongwaiio=None, position='左'):
+class HongWai(object):
+    def __init__(self, hongwai_io: int = None, position='左'):
         # 默认先使用左红外
-        self.hongwaiio = hongwaiio
+        self.hongwaiio = hongwai_io
         self.position = position
         self.hongwai_img_name = 'hongwai0'
         if self.hongwaiio or self.hongwaiio == 0:
             if hongwai_quantity['left'][0] == 'none':
-                page_info = gpio_distribute(self.hongwaiio, 'io').raise_exception()
-                gpio_distribute.message(self.hongwai_img_name, '红外传感器', 'IO', self.hongwaiio, 'IN', '0', page_info)
+                page_info = Distribute(self.hongwaiio, 'io').raise_exception()
+                Distribute.message(self.hongwai_img_name, '红外传感器', 'IO', self.hongwaiio, 'IN', '0', page_info)
                 self.hongwaicount = msg_dict['num_count']
                 hongwai_quantity['left'][0] = 'true'
                 hongwai_quantity['left'][1] = str(self.hongwaicount)
@@ -491,8 +496,8 @@ class hongwai:
                 self.hongwai_thead = threading.Thread(target=self.hongwai_threading, daemon=True)
                 self.hongwai_thead.start()
             elif hongwai_quantity['right'][0] == 'none':
-                page_info = gpio_distribute(self.hongwaiio, 'io').raise_exception()
-                gpio_distribute.message(self.hongwai_img_name, '红外传感器', 'IO', self.hongwaiio, 'IN', '0', page_info)
+                page_info = Distribute(self.hongwaiio, 'io').raise_exception()
+                Distribute.message(self.hongwai_img_name, '红外传感器', 'IO', self.hongwaiio, 'IN', '0', page_info)
                 self.hongwaicount = msg_dict['num_count']
                 hongwai_quantity['right'][0] = 'true'
                 hongwai_quantity['right'][1] = str(self.hongwaicount)
@@ -587,17 +592,23 @@ class hongwai:
             self.ioin = 1
 
 
-class servo:
+class Servo(object):
     def __init__(self, servo_io=None):
         self.servoio = servo_io
         self.servo_img_name = 'steering_engine'
         if self.servoio or self.servoio == 0:
-            page_info = gpio_distribute(self.servoio, 'io').raise_exception()
-            gpio_distribute.message(self.servo_img_name, '舵机', 'IO', self.servoio, '开', '', page_info)
+            page_info = Distribute(self.servoio, 'io').raise_exception()
+            Distribute.message(self.servo_img_name, '舵机', 'IO', self.servoio, '开', '', page_info)
             self.servoiocount = msg_dict['num_count']
         self.duty = 0
+        self.turn_on = False
 
-    def setServoAngle(self, angle):  # 设置舵机角度
+    def init_servo(self):
+        self.turn_on = True
+
+    # def setServoAngle(self, angle):  # 设置舵机角度
+    # 舵机未设计完善！！！
+    def turn(self, open_close='open', angle=0, speed=50):  # 设置舵机角度
         servo_angle = angle
         transmit_right[self.servoiocount][6][1] = ' ' + str(servo_angle) + '°'
 
@@ -612,9 +623,12 @@ class servo:
             img.angle = servo_angle
             img.draw()
 
+class Ball(pygame.sprite.Sprite):
+    def __int__(self):
+        pass
 
 # 主角
-class Mecanum_wheel:
+class Mecanum_wheel(pygame.sprite.Sprite):
     def __init__(self):
         self.actor = Actor('actors/car')
         self.actor.pos = (360, 370)
@@ -648,7 +662,7 @@ class Mecanum_wheel:
             msg_dict['exit'] = True
 
     # 设置小车速度的所有方法，用户直接调用
-    def stop(self):
+    def car_stop(self):
         self.car_speed['car_go'] = 0
         self.car_speed['car_back'] = 0
         self.car_speed['car_across_l'] = 0
@@ -657,22 +671,62 @@ class Mecanum_wheel:
         self.car_speed['car_turn_r'] = 0
         self.car_contr()
 
-    def car_go(self):
+    def car_go(self, speed=0):
+        self.car_speed['car_go'] = speed
         self.car_contr()
 
-    def car_across_l(self):
+    def car_back(self, speed=0):
+        self.car_speed['car_back'] = speed
         self.car_contr()
 
-    def car_turn_l(self):
+    def car_across_l(self, speed=0):
+        self.car_speed['car_across_l'] = speed
         self.car_contr()
 
-    def car_back(self):
+    def car_across_r(self, speed=0):
+        self.car_speed['car_across_r'] = speed
         self.car_contr()
 
-    def car_across_r(self):
+    def car_turn_l(self, speed=0):
+        self.car_speed['car_turn_l'] = speed
         self.car_contr()
 
-    def car_turn_r(self):
+    def car_turn_r(self, speed=0):
+        self.car_speed['car_turn_r'] = speed
+        self.car_contr()
+
+    def car_parallel_L_F(self, speed):
+        self.car_speed['car_go'] = speed
+        self.car_speed['car_across_l'] = speed
+        self.car_contr()
+
+    def car_parallel_R_F(self, speed):
+        self.car_speed['car_go'] = speed
+        self.car_speed['car_across_r'] = speed
+        self.car_contr()
+
+    def car_parallel_L_B(self, speed):
+        self.car_speed['car_back'] = speed
+        self.car_speed['car_across_l'] = speed
+        self.car_contr()
+
+    def car_parallel_R_B(self, speed):
+        self.car_speed['car_back'] = speed
+        self.car_speed['car_across_r'] = speed
+        self.car_contr()
+
+    def car_circle_L(self, speed, radius):  # 左传（后面不做解释了）
+        w = 110 * speed / radius
+        w = w / 12  # 转换为角速度
+        self.car_speed['car_go'] = speed
+        self.car_speed['car_turn_l'] = w
+        self.car_contr()
+
+    def car_circle_R(self, speed, radius):
+        w = 110 * speed / radius
+        w = w / 12  # 这两行一定要分开来写，不然数据帧会出现问题（符号问题看上面注释）
+        self.car_speed['car_go'] = speed
+        self.car_speed['car_turn_r'] = w
         self.car_contr()
 
     # 各个方向的速度计算
@@ -699,6 +753,10 @@ class Mecanum_wheel:
             self.actor.pos = (self.actor.x, self.actor.y)
             # 时时刻刻计算小车左右红外的位置
             # self.car_hongwai()
+
+
+
+
     # # -------------------------------------------------------
     # # 巡线必须先初始化左右两个红外，初始化后，不能更改小车红外io设置。用户直接调用
     # def before_xunxian(self, io_l, io_r):
