@@ -16,7 +16,7 @@ from pgzero import loaders
 from pgzero.screen import Screen
 from pgzero.actor import Actor
 from pgzero.rect import Rect
-from fzq_scnu import fzgpio, fzshijue1, tools, Input
+from fzq_scnu import fzgpio, fzshijue1, tools, Input, constants
 # --------------------------------------------------------------------------------------------------------
 # 控制运行的标志，空字符为不运行，非空字符为运行
 run = ''
@@ -76,6 +76,7 @@ class Update(fzgpio.Mecanum_wheel):
         screen.blit(LEVEL.level[0], LEVEL.level[1])
         screen.blit(LEVEL.racetrack[0], LEVEL.racetrack[1])
         screen.blit(LEVEL.interface[0], LEVEL.interface[1])
+        #绘画足球的位置
         # 绘制所有星星对象，用于积分
         if self.stars:
             for st in self.stars:
@@ -89,10 +90,13 @@ class Update(fzgpio.Mecanum_wheel):
         self.draw_t('下一页', (pageforward_rect.x+pageforward_rect.w/2, pageforward_rect.y+pageforward_rect.h/2))
         # 文本框
         self.draw_t('文本框', fzgpio.texts_pos_sitting['文本框'])
-        self.draw_t('场景长宽约: 3m*2m', fzgpio.texts_pos_sitting['场景长宽约: 3m*2m'])
-        self.draw_t('前进速度(mm/s): '+str(round(math.sqrt(fzgpio.msg_dict['actor'][1]['contr_fb']**2 +
-                                       fzgpio.msg_dict['actor'][1]['contr_lr']**2), 1)),
-                    fzgpio.texts_pos_sitting['前进速度(mm/s): '])
+        self.draw_t('场景长宽约:3m*2m', fzgpio.texts_pos_sitting['场景长宽约:3m*2m'])
+        fb = ''
+        if fzgpio.msg_dict['actor'][1]['contr_fb'] < 0:
+            fb = '-'
+        self.draw_t('前进速度(mm/s):'+fb+str(round(math.sqrt(fzgpio.msg_dict['actor'][1]['contr_fb']**2 +
+                    fzgpio.msg_dict['actor'][1]['contr_lr']**2), 1)),
+                    fzgpio.texts_pos_sitting['前进速度(mm/s):'])
         # 积分
         self.draw_t('分数：' + str(self.score), (1050, 678))
 
@@ -108,7 +112,7 @@ class Update(fzgpio.Mecanum_wheel):
                     img.pos = value[1]
                     img.draw()  # 绘制传感器
                     self.draw_t(value[2], value[3])  # 绘制接口类型和接口位号
-                    fzgpio.servo.servo_angle_control(value[2], value[1], value[6][1])  # 舵机旋转角度图像绘制
+                    fzgpio.Servo.servo_angle_control(value[2], value[1], value[6][1])  # 舵机旋转角度图像绘制
                     for i in range(2):  # 绘制两个文本
                         self.draw_t(value[4][i], value[5][i])
                         self.draw_t(value[6][i], value[7][i])
@@ -117,7 +121,7 @@ class Update(fzgpio.Mecanum_wheel):
                     img.pos = value[1]
                     img.draw()
                     self.draw_t(value[2], value[3])
-                    fzgpio.servo.servo_angle_control(value[2], value[1], value[6][1])
+                    fzgpio.Servo.servo_angle_control(value[2], value[1], value[6][1])
                     for i in range(2):
                         self.draw_t(value[4][i], value[5][i])
                         self.draw_t(value[6][i], value[7][i])
@@ -126,7 +130,7 @@ class Update(fzgpio.Mecanum_wheel):
                     img.pos = value[1]
                     img.draw()
                     self.draw_t(value[2], value[3])
-                    fzgpio.servo.servo_angle_control(value[2], value[1], value[6][1])
+                    fzgpio.Servo.servo_angle_control(value[2], value[1], value[6][1])
                     for i in range(2):
                         self.draw_t(value[4][i], value[5][i])
                         self.draw_t(value[6][i], value[7][i])
@@ -153,7 +157,7 @@ class Update(fzgpio.Mecanum_wheel):
         # 温湿度手动设置
         if fzgpio.transmit_right:
             for key, value in list(fzgpio.transmit_right.items()):
-                result = fzgpio.tmp_hum.tmp_hum_input(value[2])
+                result = fzgpio.TempHump.tmp_hum_input(value[2])
                 if result:
                     InpurBox_temp.draw()
                     InpurBox_humi.draw()
@@ -164,16 +168,16 @@ class Update(fzgpio.Mecanum_wheel):
         # 绘制当前温湿度并绘制
         if fzgpio.texts_pos_sitting:
             if fzgpio.tmp_hum_data['temp'] and fzgpio.tmp_hum_data['humi']:
-                self.draw_t(('当前温度(℃): ' + str(fzgpio.tmp_hum_data['temp'])),
-                            constants.texts_pos_sitting['当前温度(℃): '])
-                self.draw_t(('当前湿度(%): ' + str(fzgpio.tmp_hum_data['humi'])),
-                            constants.texts_pos_sitting['当前湿度(%): '])
+                self.draw_t(('当前温度(℃):' + str(fzgpio.tmp_hum_data['temp'])),
+                            constants.texts_pos_sitting['当前温度(℃):'])
+                self.draw_t(('当前湿度(%):' + str(fzgpio.tmp_hum_data['humi'])),
+                            constants.texts_pos_sitting['当前湿度(%):'])
             elif fzgpio.tmp_hum_data['temp']:
-                self.draw_t(('当前温度(℃): ' + str(fzgpio.tmp_hum_data['temp'])),
-                            constants.texts_pos_sitting['当前温度(℃): '])
+                self.draw_t(('当前温度(℃):' + str(fzgpio.tmp_hum_data['temp'])),
+                            constants.texts_pos_sitting['当前温度(℃):'])
             elif fzgpio.tmp_hum_data['humi']:
-                self.draw_t(('当前湿度(%): ' + str(fzgpio.tmp_hum_data['humi'])),
-                            constants.texts_pos_sitting['当前湿度(%): '])
+                self.draw_t(('当前湿度(%):' + str(fzgpio.tmp_hum_data['humi'])),
+                            constants.texts_pos_sitting['当前湿度(%):'])
 
     # 小车图像刷新
     def draw_car(self):
@@ -282,11 +286,11 @@ class Update(fzgpio.Mecanum_wheel):
                 print(result)
                 sys.exit(0)
 
+    # 积分刷新
     def score_update(self):
         if fzgpio.msg_dict['actor'][0] == 1:
             self.actor_big_rect = Rect((self.actor.left - 10, self.actor.top - 10),
                                        (self.actor.width + 20, self.actor.height + 20))
-            csb_collide = False
             if self.stars:
                 for num, star in enumerate(self.stars):
                     star_rect = Rect((star.x, star.y), (star.width, star.height))
@@ -302,6 +306,8 @@ class Update(fzgpio.Mecanum_wheel):
                     elif collide_or_not:
                         del star, self.stars[num]
                         self.score += round(100/len(LEVEL.level[3][1]))
+            else:
+                self.score = 100
 
     # 运行监听
     @staticmethod
@@ -326,11 +332,9 @@ class Update(fzgpio.Mecanum_wheel):
         # 设置daemon参数，最终目的是为了，在点击仿真界面右上角的叉叉关闭仿真器的时候，立即结束进程，避免主线程仍在等待子线程结束
         code_threading = threading.Thread(target=self.code, daemon=True)
         code_threading.start()
-
-
 # --------------------------------------------------------------------------------------------------------
 def on_mouse_down(pos, button):
-    print(pos)
+    # print(pos)
     # 点击鼠标右键给右边的硬件展示画面翻页
     if button == 1:
         if pageback_rect.collidepoint(pos[0], pos[1]):
@@ -363,6 +367,9 @@ def on_key_up():
 # 仿真器运行
 if run != '':
     import pgzrun
+    # app = QApplication(sys.argv)
+    # app.aboutToQuit.connect(app.deleteLater)
+    # gui = GenMast()
 
     # 必须'def draw()'和'def update()',原设定就是如此,即无限循环执行draw()和update()
     # 当然，也可以在game.py里的PGZeroGame.mainloop()设置无限循环
@@ -382,12 +389,12 @@ if run != '':
         Update.fzq_over()
     # --------------------------------------------------------------------------------------------------------
     # 设置根路径（也就是仿真所需要的图像路径，此处由change.py写入）
-    # files_path = 'C:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\'
+    # files_path = "con:\\Users\\86137\\Documents\\python_code\\fzq_test\\emulator_files\\"
     files_path = ''
     loaders.set_root(files_path)
     # 获取constants.py文件的位置，并导入
-    sys.path.append(files_path)
-    import constants
+    # sys.path.append(files_path)
+    # import constants
     # 关卡设置：
     LEVEL = constants.Level()
     # 获取储存日志的位置，记录报错内容
@@ -396,7 +403,7 @@ if run != '':
     # --------------------------------------------------------------------------------------------------------
     # 窗口设置
     # screen : Screen
-    screen = Screen(pygame.image.load(files_path + 'images\\interfaces\\interface_none.png'))
+    screen = Screen(pygame.image.load(files_path + "images\\interfaces\\interface_none.png"))
     WIDTH, HEIGHT = constants.WIDTH, constants.HEIGHT
     os.environ['SDL_VIDEO_CENTERED'] = '1'
     TITLE = constants.TITLE
@@ -432,6 +439,7 @@ if run != '':
     # pgzrun.go()为死循环,也就是game.py里的PGZeroGame.mainloop()所设置的无限循环。
     pgzrun.go()
     # 以下语句只能在仿真器结束后执行。
+    # sys.exit(app.exec_())
     print('仿真器运行结束')
 else:
     pass
